/*
  EleKin_v
    Electrokinetics - Electric scalar potential v formulation
*/

/* I N P U T
   ---------

  GlobalGroup :  (Extension '_Ele' is for Electric problem)
  -----------
    Domain_Ele               Whole electric domain
    DomainC_Ele              Conducting regions

  Function :
  --------
    sigma[]                  Electric conductivity

  Constraint :
  ----------
    ElectricScalarPotential  Fixed electric scalar potential
                             (classical boundary condition)
    GlobalElectricPotential  Fixed global electric scalar potential
                             (for perfect electrodes)

  Physical constants :
  ------------------
*/

    eps0 = 8.854187818e-12 ;

/* O U T P U T
   -----------

  PostQuantities :
  --------------
   v : Electric scalar potential
   e : Electric field
   j : Electric current density

*/

/* --------------------------------------------------------------------------*/

Group {
  DefineGroup[ Domain_Ele, DomainC_Ele ] ;
}

Function {
  DefineFunction[ sigma ] ;
}


/* --------------------------------------------------------------------------*/

FunctionSpace {
  { Name Hgrad_v_EleKin ; Type Form0 ;
    BasisFunction {
      // v = v  s
      //      n  n
      { Name sn ; NameOfCoef vn ; Function BF_Node ;
        Support DomainC_Ele ; Entity NodesOf[ All ] ; }
    }
    Constraint {
      { NameOfCoef vn ;
        EntityType NodesOf ; NameOfConstraint ElectricScalarPotential ; }

      { NameOfCoef vn ;
        EntityType NodesOf ; NameOfConstraint GlobalElectricPotential ; }
    }
  }
}


Formulation {
  { Name Electrokinetics_v ; Type FemEquation ;
    Quantity {
      { Name v ; Type Local ; NameOfSpace Hgrad_v_EleKin ; }
    }
    Equation {
      Galerkin { [ sigma[] * Dof{d v} , {d v} ] ;
                 In DomainC_Ele ;
                 Jacobian Vol ; Integration GradGrad ; }
    }
  }
}


Resolution {
  { Name EleKin_v ;
    System {
      { Name Sys_EleKin ; NameOfFormulation Electrokinetics_v ; }
    }
    Operation {
      Generate Sys_EleKin ; Solve Sys_EleKin ; SaveSolution Sys_EleKin ;
    }
  }
}


PostProcessing {
  { Name EleKin_v ; NameOfFormulation Electrokinetics_v ;
    PostQuantity {
      { Name v ; Value { Term { [ {v} ]              ; In DomainC_Ele ; } } }
      { Name e ; Value { Term { [ -{d v} ]           ; In DomainC_Ele ; } } }
      { Name j ; Value { Term { [ -sigma[] * {d v} ] ; In DomainC_Ele ; } } }
      { Name f ; Value { Term { [ -sigma[] * {d v} /\ bext[] ] ; In DomainC_Ele ; } } }
    }
  }
}


/* --------------------------------------------------------------------------*/
/* --------------------------------------------------------------------------*/
